@@ -9,7 +9,7 @@
 ####################################################################################################
 
 HERE="$(cd "$(dirname "$0")" && pwd -P)"
-TEST=acc_bench_smm
+TEST=acc_bench
 EXE=${HERE}/../../${TEST}
 
 if [ ! -e "$1" ]; then
